"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.link = exports.border = exports.rounded = exports.round = exports.fw = exports.fs = exports.lh = exports.maxW = exports.w = exports.maxWidth = exports.width = exports.color = exports.bg = exports.p = exports.py = exports.px = exports.pb = exports.pt = exports.pr = exports.pl = exports.m = exports.my = exports.mx = exports.mb = exports.mt = exports.mr = exports.ml = exports.centerY = exports.centerX = exports.flexCol = exports.justifyBetween = exports.justifyContent = exports.alignItems = exports.flexDirection = exports.flexWrap = exports.inlineFlex = exports.flex = exports.inline = exports.block = exports.hidden = exports.mq = exports.down = exports.up = exports.selectMqDown = exports.selectMqUp = exports.name = void 0;

var _core = require("@emotion/core");

var _ramda = require("ramda");

var _facepaint = _interopRequireDefault(require("facepaint"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var name = 'monad-ui';
/* MEDIA QUERIES */

exports.name = name;
var breakpoints = {
  sm: '576px',
  md: '768px',
  lg: '992px',
  xl: '1200px'
};

var selectMqUp = function selectMqUp(size) {
  return (0, _ramda.compose)(function (bp) {
    return "@media (min-width: ".concat(bp, ")");
  }, (0, _ramda.prop)(size))(breakpoints);
};

exports.selectMqUp = selectMqUp;

var selectMqDown = function selectMqDown(size) {
  return (0, _ramda.compose)(function (bp) {
    return "@media (max-width: ".concat(bp, ")");
  }, (0, _ramda.prop)(size))(breakpoints);
};

exports.selectMqDown = selectMqDown;

var up = function up(size) {
  return function (style) {
    return _defineProperty({}, selectMqUp(size), style);
  };
};

exports.up = up;

var down = function down(size) {
  return function (style) {
    return _defineProperty({}, selectMqDown(size), style);
  };
}; // Use up by default for media queries


exports.down = down;
var mq = up;
exports.mq = mq;
var facepaintMq = (0, _facepaint["default"])(Object.keys(breakpoints).map(selectMqUp));

var responsiveStyle = function responsiveStyle(prop, val) {
  // If style is composed
  if (Array.isArray(prop)) {
    return (0, _core.css)(prop.map(function (fn) {
      return fn(val);
    }));
  }

  if (Array.isArray(val)) {
    return (0, _core.css)(facepaintMq(_defineProperty({}, prop, val)));
  }

  if (_typeof(val) === "object") {
    return (0, _core.css)(facepaintMq(_defineProperty({}, prop, Object.keys(breakpoints).map(function (size) {
      var valueForThisQuery = val[size];

      if (!valueForThisQuery) {
        return undefined;
      }

      return val[size];
    }))));
  } // If It's a not Array and not Object


  return (0, _core.css)(_defineProperty({}, prop, val));
};
/* DISPLAY */


var hidden = (0, _core.css)({
  display: 'none'
});
exports.hidden = hidden;
var block = (0, _core.css)({
  display: 'block'
});
exports.block = block;
var inline = (0, _core.css)({
  display: 'inline'
});
exports.inline = inline;
var flex = (0, _core.css)({
  display: 'flex'
});
exports.flex = flex;
var inlineFlex = (0, _core.css)({
  display: 'inline-flex'
});
/* FLEX */

exports.inlineFlex = inlineFlex;

var flexWrap = function flexWrap() {
  var arg = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'wrap';
  return responsiveStyle('flexWrap', arg);
};

exports.flexWrap = flexWrap;

var flexDirection = function flexDirection(arg) {
  return responsiveStyle('flexDirection', arg);
};

exports.flexDirection = flexDirection;

var alignItems = function alignItems(arg) {
  return responsiveStyle('alignItems', arg);
};

exports.alignItems = alignItems;

var justifyContent = function justifyContent(arg) {
  return responsiveStyle('justifyContent', arg);
};

exports.justifyContent = justifyContent;
var justifyBetween = (0, _core.css)(justifyContent('space-between'));
exports.justifyBetween = justifyBetween;
var flexCol = flexDirection('column');
/* Flex Utility */

exports.flexCol = flexCol;
var centerX = (0, _core.css)(flex, {
  justifyContent: 'center'
});
exports.centerX = centerX;
var centerY = (0, _core.css)(flex, alignItems('center'));
/* MARGIN */

exports.centerY = centerY;

var ml = function ml(arg) {
  return responsiveStyle('marginLeft', arg);
};

exports.ml = ml;

var mr = function mr(arg) {
  return responsiveStyle('marginRight', arg);
};

exports.mr = mr;

var mt = function mt(arg) {
  return responsiveStyle('marginTop', arg);
};

exports.mt = mt;

var mb = function mb(arg) {
  return responsiveStyle('marginBottom', arg);
};

exports.mb = mb;

var mx = function mx(arg) {
  return responsiveStyle([ml, mr], arg);
};

exports.mx = mx;

var my = function my(arg) {
  return responsiveStyle([mb, mt], arg);
};

exports.my = my;

var m = function m(arg) {
  return responsiveStyle([my, mx], arg);
};
/* PADDING */


exports.m = m;

var pl = function pl(arg) {
  return responsiveStyle('paddingLeft', arg);
};

exports.pl = pl;

var pr = function pr(arg) {
  return responsiveStyle('paddingRight', arg);
};

exports.pr = pr;

var pt = function pt(arg) {
  return responsiveStyle('paddingTop', arg);
};

exports.pt = pt;

var pb = function pb(arg) {
  return responsiveStyle('paddingBottom', arg);
};

exports.pb = pb;

var px = function px(arg) {
  return responsiveStyle([pl, pr], arg);
};

exports.px = px;

var py = function py(arg) {
  return responsiveStyle([pt, pb], arg);
};

exports.py = py;

var p = function p(arg) {
  return responsiveStyle([px, py], arg);
};
/* COLOR */


exports.p = p;

var bg = function bg(arg) {
  return responsiveStyle('background', arg);
};

exports.bg = bg;

var color = function color(arg) {
  return responsiveStyle('color', arg);
};
/* Size */


exports.color = color;

var width = function width(arg) {
  return responsiveStyle('width', arg);
};

exports.width = width;

var maxWidth = function maxWidth(arg) {
  return responsiveStyle('maxWidth', arg);
};

exports.maxWidth = maxWidth;
var w = width;
exports.w = w;
var maxW = maxWidth;
/* Typography */

exports.maxW = maxW;

var lh = function lh(arg) {
  return responsiveStyle('lineHeight', arg);
};

exports.lh = lh;

var fs = function fs(arg) {
  return responsiveStyle('fontSize', arg);
};

exports.fs = fs;

var fw = function fw(arg) {
  return responsiveStyle('fontWeight', arg);
};
/* Border */


exports.fw = fw;

var round = function round(arg) {
  return responsiveStyle('borderRadius', arg);
};

exports.round = round;
var rounded = round('.25rem');
exports.rounded = rounded;

var border = function border(arg) {
  return responsiveStyle('border', arg);
};
/* LINK HELPER */


exports.border = border;
var link = (0, _core.css)({
  textDecoration: 'none',
  color: 'inherit',
  cursor: 'pointer'
});
exports.link = link;
//# sourceMappingURL=index.js.map